@@ -64,12 +64,12 @@ use lib qw(../lib);
 	sub on_poco_irc_001 {
 		my $self = shift;
 		print "Connected.  Joining a channel...\n";
-		$self->component->yield(join => "#poe");
+		$self->component->yield(join => "#reflex");
 	}
 
 	sub on_poco_irc_public {
-		my ($self, $args) = @_;
-		my ($who, $where, $what) = @$args{0,1,2};
+		my ($self, $event) = @_;
+		my ($who, $where, $what) = @{$event->args()}[0,1,2];
 
 		my $nick = (split /!/, $who)[0];
 		my $channel = $where->[0];
