@@ -1,4 +1,4 @@
-# $Id$
+# vim: ts=2 sw=2 noexpandtab
 
 # RS Nor latch.
 #
@@ -19,13 +19,13 @@ use Moose;
 extends 'Reflex::Base';
 use Ttl::Nor;
 
-use Reflex::Trait::Observed;
-use Reflex::Trait::EmitsOnChange;
+use Reflex::Trait::Watched qw(watches);
+use Reflex::Trait::EmitsOnChange qw(emits);
 
-observes nor_r => ( isa => 'Ttl::Nor', handles => { r => 'a' } );
-observes nor_s => ( isa => 'Ttl::Nor', handles => { s => 'b' } );
-emits    q     => ( isa => 'Bool'                              );
-emits    not_q => ( isa => 'Bool'                              );
+watches nor_r => ( isa => 'Ttl::Nor', handles => { r => 'a' } );
+watches nor_s => ( isa => 'Ttl::Nor', handles => { s => 'b' } );
+emits   q     => ( isa => 'Bool'                              );
+emits   not_q => ( isa => 'Bool'                              );
 
 sub on_nor_s_out {
 	my ($self, $args) = @_;
