@@ -1,4 +1,4 @@
-# $Id$
+# vim: ts=2 sw=2 noexpandtab
 
 # Logical NAND gate.  Built from NOT + AND.
 # a b out
@@ -13,27 +13,27 @@ extends 'Ttl::Bin';
 use Ttl::Not;
 use Ttl::And;
 
-use Reflex::Trait::Observed;
+use Reflex::Trait::Watched qw(watches);
 
-observes and => (
-  isa     => 'Ttl::And',
-  handles => [qw(a b)],
+watches and => (
+	isa     => 'Ttl::And',
+	handles => [qw(a b)],
 	setup   => sub { Ttl::And->new() },
 );
 
-observes not => (
-  isa     => 'Ttl::Not',
+watches not => (
+	isa     => 'Ttl::Not',
 	setup   => sub { Ttl::Not->new() },
 );
 
 sub on_and_out {
-  my ($self, $args) = @_;
-  $self->not->in($args->{value});
+	my ($self, $args) = @_;
+	$self->not->in($args->{value});
 }
 
 sub on_not_out {
-  my ($self, $args) = @_;
-  $self->out($args->{value});
+	my ($self, $args) = @_;
+	$self->out($args->{value});
 }
 
 1;
