@@ -1,5 +1,5 @@
-pacakage MooseX::Role::Reactive;
-
+package MooseX::Role::Reactive;
+$MooseX::Role::Reactive::VERSION = '0.100';
 use Moose::Role;
 
 # This is a namespace reservation for the emit/watch part of
@@ -9,15 +9,16 @@ use Moose::Role;
 1;
 
 __END__
-=pod
 
-=for :stopwords Rocco Caputo
+=pod
 
 =encoding UTF-8
 
+=for :stopwords Rocco Caputo
+
 =head1 VERSION
 
-This document describes version 0.099, released on April 21, 2013.
+This document describes version 0.100, released on April 02, 2017.
 
 =head1 SEE ALSO
 
@@ -42,7 +43,7 @@ Rocco Caputo <rcaputo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Rocco Caputo.
+This software is copyright (c) 2017 by Rocco Caputo.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -77,4 +78,3 @@ SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
 DAMAGES.
 
 =cut
-
