@@ -1,9 +1,6 @@
 package Reflex;
-{
-  $Reflex::VERSION = '0.099';
-}
 # vim: ts=2 sw=2 noexpandtab
-
+$Reflex::VERSION = '0.100';
 use warnings;
 use strict;
 
@@ -40,22 +37,22 @@ sub run_all {
 
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =for :stopwords Rocco Caputo cpan testmatrix url annocpan anno bugtracker rt cpants
 kwalitee diff irc mailto metadata placeholders metacpan
 
-=encoding UTF-8
-
 =head1 NAME
 
 Reflex - Class library for flexible, reactive programs.
 
 =head1 VERSION
 
-This document describes version 0.099, released on April 21, 2013.
+This document describes version 0.100, released on April 02, 2017.
 
 =head1 SYNOPSIS
 
@@ -423,11 +420,11 @@ L<L<Moose>, L<POE>, the Reflex and Reflexive namespaces on CPAN.|L<Moose>, L<POE
 
 =item *
 
-L<Ohlo - https://www.ohloh.net/p/reflex-perl|Ohlo - https://www.ohloh.net/p/reflex-perl>
+L<Ohlo - L<https://www.ohloh.net/p/reflex-perl>|Ohlo - L<https://www.ohloh.net/p/reflex-perl>>
 
 =item *
 
-L<CIA - http://cia.vc/stats/project/reflex|CIA - http://cia.vc/stats/project/reflex>
+L<CIA - L<http://cia.vc/stats/project/reflex>|CIA - L<http://cia.vc/stats/project/reflex>>
 
 =back
 
@@ -468,7 +465,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Reflex>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Reflex>
 
 =item *
 
@@ -500,7 +497,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/Reflex>
+L<http://cpants.cpanauthors.org/dist/Reflex>
 
 =item *
 
@@ -552,7 +549,7 @@ You can connect to the server at 'irc.perl.org' and join this channel: #reflex t
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-reflex at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Reflex>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Reflex>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
@@ -561,8 +558,6 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://github.com/rcaputo/reflex>
-
   git clone git://github.com/rcaputo/reflex.git
 
 =head1 BUGS AND LIMITATIONS
@@ -586,7 +581,7 @@ lengthy and sometimes irrelevant design discussion for oh so long.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Rocco Caputo.
+This software is copyright (c) 2017 by Rocco Caputo.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -621,7 +616,3 @@ SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
 DAMAGES.
 
 =cut
-
-
-__END__
-
