@@ -1,7 +1,6 @@
 package Reflex::Eg;
-{
-  $Reflex::Eg::VERSION = '0.099';
-}
+$Reflex::Eg::VERSION = '0.100';
+use Moose;
 
 __PACKAGE__->meta->make_immutable;
 
@@ -11,23 +10,34 @@ __PACKAGE__->meta->make_immutable;
 # vim: ts=2 sw=2 expandtab
 
 __END__
-=pod
 
-=for :stopwords Rocco Caputo
+=pod
 
 =encoding UTF-8
 
+=for :stopwords Rocco Caputo
+
+=head1 NAME
+
+Reflex::Eg - Reflex examples namespace
+
 =head1 VERSION
 
-This document describes version 0.099, released on April 21, 2013.
-
-=abstract Index of Reflex Examples
+This document describes version 0.100, released on April 02, 2017.
 
 =head1 EXAMPLES
 
+Index of examples using this namespace:
+
 =over 4
 
-=index ^Reflex::Eg::
+=item *
+
+L<Reflex::Eg::Inheritance::Moose>
+
+=item *
+
+L<Reflex::Eg::Inheritance::Plain>
 
 =back
 
@@ -54,7 +64,7 @@ Rocco Caputo <rcaputo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Rocco Caputo.
+This software is copyright (c) 2017 by Rocco Caputo.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -89,4 +99,3 @@ SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
 DAMAGES.
 
 =cut
-
