@@ -1,8 +1,5 @@
 package Reflex::Eg::Inheritance::Moose;
-{
-  $Reflex::Eg::Inheritance::Moose::VERSION = '0.099';
-}
-
+$Reflex::Eg::Inheritance::Moose::VERSION = '0.100';
 use Moose;
 extends 'Reflex::Timeout';
 
@@ -15,20 +12,26 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
-
-
 =pod
 
-=for :stopwords Rocco Caputo
-
 =encoding UTF-8
 
+=for :stopwords Rocco Caputo
+
+=head1 NAME
+
+Reflex::Eg::Inheritance::Moose - Inheriting a Reflex timer using Moose.
+
 =head1 VERSION
 
-This document describes version 0.099, released on April 21, 2013.
+This document describes version 0.100, released on April 02, 2017.
 
 =head1 SYNOPSIS
 
+Usage:
+
+  perl -M[% doc.module %] -e '[% doc.module %]->new(delay => 1)->run_all'
+
 =head1 DESCRIPTION
 
 Reflex::Timeout objects normally go dormant after the first time they
@@ -44,14 +47,6 @@ apparent it works.
 This is a relatively silly exercise.
 Reflex::Interval already implements a periodic interval timer.
 
-=abstract Inheriting a Reflex timer using Moose.
-
-=example Reflex::Eg::Inheritance::Moose
-
-Usage:
-
-  perl -M[% doc.module %] -e '[% doc.module %]->new(delay => 1)->run_all'
-
 =head1 SEE ALSO
 
 Please see those modules/websites for more information related to this module.
@@ -75,7 +70,7 @@ Rocco Caputo <rcaputo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Rocco Caputo.
+This software is copyright (c) 2017 by Rocco Caputo.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -111,7 +106,6 @@ DAMAGES.
 
 =cut
 
-
 __END__
 
 
